@@ -4,7 +4,6 @@ import (
 	"github.com/openshift/cluster-logging-operator/pkg/controller/clusterlogging"
 	"github.com/openshift/cluster-logging-operator/pkg/controller/collector"
 	"github.com/openshift/cluster-logging-operator/pkg/controller/forwarding"
-	"github.com/openshift/cluster-logging-operator/pkg/controller/kibanasecret"
 	"github.com/openshift/cluster-logging-operator/pkg/controller/proxyconfig"
 	"github.com/openshift/cluster-logging-operator/pkg/controller/trustedcabundle"
 )
@@ -16,6 +15,5 @@ func init() {
 		forwarding.Add,
 		collector.Add,
 		proxyconfig.Add,
-		kibanasecret.Add,
 		trustedcabundle.Add)
 }
