@@ -22,8 +22,8 @@ import (
 //TODO: Remove this in the next release after removing old kibana code completely
 func TestHasCLORef(t *testing.T) {
 	clr := ClusterLoggingRequest{
-		client: nil,
-		cluster: &logging.ClusterLogging{
+		Client: nil,
+		Cluster: &logging.ClusterLogging{
 			TypeMeta: metav1.TypeMeta{},
 			ObjectMeta: metav1.ObjectMeta{
 				Name:                       "cluster-logging",
@@ -75,7 +75,7 @@ func TestHasCLORef(t *testing.T) {
 		Status: apps.DeploymentStatus{},
 	}
 
-	utils.AddOwnerRefToObject(obj, utils.AsOwner(clr.cluster))
+	utils.AddOwnerRefToObject(obj, utils.AsOwner(clr.Cluster))
 
 	t.Log("refs:", obj.GetOwnerReferences())
 	if !HasCLORef(obj, &clr) {
@@ -354,14 +354,14 @@ func TestRemoveKibanaCR(t *testing.T) {
 	}
 
 	clr := &ClusterLoggingRequest{
-		cluster: &logging.ClusterLogging{
+		Cluster: &logging.ClusterLogging{
 			ObjectMeta: metav1.ObjectMeta{
 				Namespace: "openshift-logging",
 			},
 		},
 	}
 
-	clr.client = fake.NewFakeClient(kbn)
+	clr.Client = fake.NewFakeClient(kbn)
 
 	if err := clr.removeKibanaCR(); err != nil {
 		t.Error(err)
